# API Documentation

This includes a thorough documentation of all pertinent modules, functions,
and classes contained within **primer3-py**.

```{toctree}
:maxdepth: 2

bindings
thermoanalysis
p3helpers
```
